==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.g(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        ListPanelItemModelDescriptionMetadata.d(a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("Model", "ExportedType:ListPanelItemModel");
        a.item("ContentRef", "(w:Content,wf:Content)DataRef");
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
        a.u("ListPanelTemplateItemUpdatingEventArgs", function () { return new ListPanelTemplateItemUpdatingEventArgsDescription(); });
        a.t("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelItemModelDescriptionMetadata } from "./ListPanelItemModelDescriptionMetadata";
import { ListPanelTemplateItemUpdatingEventArgsDescription } from "./ListPanelTemplateItemUpdatingEventArgsDescription";
/**
 * @hidden
 */
var ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, _super);
    function ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a == null) {
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.j(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
        ListPanelItemModelDescriptionMetadata.d(a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("Model", "ExportedType:ListPanelItemModel");
        a.item("ContentRef", "(w:Content,wf:Content)DataRef");
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.d = function (a) {
        ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.b(a);
        a.aa("ListPanelTemplateItemUpdatingEventArgs", function () { return new ListPanelTemplateItemUpdatingEventArgsDescription(); });
        a.z("ListPanelTemplateItemUpdatingEventArgs", ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a);
    };
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.$t = markType(ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata, 'ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata');
    ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata.a = null;
    return ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata;
}(Base));
export { ListPanelTemplateItemUpdatingEventArgsDescriptionMetadata };
